Sangfroid is a Python library to read [Synfig](https://synfig.org) documents, in the .sif, .sifz, and .sfg formats. It isn't ready for general use yet.

The current version is [0.1 *liverpool*](https://gitlab.com/marnanel/sangfroid/-/milestones/1). There may be improvements in development, which happens [on gitlab](https://gitlab.com/marnanel/sangfroid). There's also [a github mirror](https://github.com/marnanel/sangfroid), updated irregularly.

The [main place to find documentation](https://sangfroid.readthedocs.io/) is on RTD, or equivalently in the docs/ directory of this distribution.

# How to install

Short answer:

* `pip install .` (That's a full stop at the end.)

Long answer:

* `git clone https://gitlab.com/marnanel/sangfroid.git`
* `cd sangfroid`
* `python3 -m venv venv`
* `. venv/bin/activate`
* `python -m pip install .`

# Get involved

* Drop by on [our Discord server](https://discord.gg/2eAHdQTUyb).
* [Raise issues](https://gitlab.com/marnanel/sangfroid/-/issues/). We like issues.
* Post questions and suggestions on [Synfig's own forums](https://forums.synfig.org/), using the tag `#sangfroid`.
